<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-urls?lang_cible=br
// ** ne pas modifier le fichier **

return [

	// U
	'urls_description' => 'Merañ an adstummoù URL sklaer pe ket',
	'urls_slogan' => 'Merañ an adstummoù URL sklaer pe ket',
];
